==> haskell-uuid-1.3.11-7-armv7h.pkg.tar.xz: usr/share/haskell/haskell-uuid/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.11
id: uuid-1.3.11-88963c9f5cc3f56cbc943d5b6ea5ce69
key: uuid_ATe83ABgxRjHt0P8K8eFNr
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.11
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.11
hs-libraries: HSuuid-1.3.11-ATe83ABgxRjHt0P8K8eFNr
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptohash-0.11.9-66ecf9651f97183101697edd4149971c
    network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    uuid-types-1.0.2-31d0afe3e94388f95aaba92ed882146a
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"

==> haskell-uuid-1.3.12-1-armv7h.pkg.tar.xz: usr/share/haskell/haskell-uuid/register.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: uuid
version: 1.3.12
id: uuid-1.3.12-84f229c814727c5af1ad08339e489d01
key: uuid_4hPK7QrBrnCBnkNJqrd93M
license: BSD3
copyright: (c) 2008-2014 Antoine Latter
maintainer: aslatter@gmail.com
homepage: https://github.com/aslatter/uuid
synopsis: For creating, comparing, parsing and printing Universally Unique Identifiers
description:
    This library is useful for creating, comparing, parsing and
    printing Universally Unique Identifiers.
    See <http://en.wikipedia.org/wiki/UUID> for the general idea.
category: Data
author: Antoine Latter
exposed: True
exposed-modules:
    Data.UUID Data.UUID.Util Data.UUID.V1 Data.UUID.V3 Data.UUID.V4
    Data.UUID.V5
hidden-modules: Data.UUID.Named Data.Word.Util
trusted: False
import-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.12
library-dirs: /usr/lib/ghc-7.10.3/site-local/uuid-1.3.12
data-dir: /usr/share/arm-linux-ghc-7.10.3/uuid-1.3.12
hs-libraries: HSuuid-1.3.12-4hPK7QrBrnCBnkNJqrd93M
depends:
    base-4.8.2.0-2f1f71a7fcf013cd47fd21f489064f9a
    binary-0.7.5.0-29f7044fa0b12dc5c2dcec897db5c464
    bytestring-0.10.6.0-3b51e35daa3fe2a56ecd3687fb389cdc
    cryptonite-0.13-349d06636b05d6ecd7f57ca79abfe077
    memory-0.11-3a745e41fe78387f608c420e9b455d25
    network-info-0.2.0.8-bc6c8aa48b93ac2c06aa2e5c4fa39eb6
    random-1.1-41a0a7ecd483c665a5c3a093a5be2968
    text-1.2.2.1-18afbfeccf88d72c4b6e468c86d2b77d
    time-1.5.0.1-cf94b0d806e26f6c4e356671290061b2
    uuid-types-1.0.3-129ee1a49c60bed5953b3255a879f830
haddock-interfaces: /usr/share/doc/haskell-uuid/html/uuid.haddock
haddock-html: /usr/share/doc/haskell-uuid/html
' | '/usr/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
